@@ -31,6 +31,17 @@ from plonehrm.contracts import ContractsMessageFactory as _
 
 
 schema = Schema((
+    StringField(name='template',
+        required=1,
+        vocabulary='_templates',
+        read_permission='plonehrm: View hrm content',
+        write_permission='plonehrm: Modify contract',
+        widget=SelectionWidget(
+            format='select',
+            condition='not:object/template_chosen',
+            label=_(u'contract_label_template', default=u'Template'),
+        ),
+    ),
     FixedPointField(
         name='wage',
         read_permission='plonehrm: View hrm content',
@@ -110,17 +121,6 @@ schema = Schema((
             label=_(u'contract_label_hours', default=u'Number of hours'),
         )
     ),
-    StringField(name='template',
-        required=1,
-        vocabulary='_templates',
-        read_permission='plonehrm: View hrm content',
-        write_permission='plonehrm: Modify contract',
-        widget=SelectionWidget(
-            format='select',
-            condition='not:object/template_chosen',
-            label=_(u'contract_label_template', default=u'Template'),
-        ),
-    ),
     TextField(name='text',
         required=False,
         seachable=False,
@@ -180,56 +180,6 @@ class Contract(BaseContent):
             items = [(item.id, item.Title()) for item in tool.contentValues()]
             return DisplayList(items)
 
-    security.declarePrivate('setTemplate')
-    def setTemplate(self, value):
-        """When setting the template, we want to change the main text.
-
-        Note: this *MUST* be the last parameter that is set, so it
-        MUST be the last field that is visible on the form, else wage
-        and function will not be set.
-        """
-
-        # XXX: Remove view lookup
-        # A content class should not need to be aware of the request in
-        # order to preserve separation of concerns.  The subsitution
-        # mechanism here should be replaced with a component that doesn't
-        # know or care about the request - Rocky
-        view = component.queryMultiAdapter((self, self.REQUEST),
-                                           name=u'substituter')
-        if view is None:
-            raise ValueError('Components are not properly configured, could '
-                             'not find "substituter" view')
-
-        tool = getToolByName(self, 'portal_contracts', None)
-        if tool is None or value not in tool.contentIds():
-            # Hm, odd.
-            return
-        self.template = value
-
-        # Get the text from the template
-        template_object = tool[self.template]
-        template_text = template_object.getText()
-
-        template_text = view.substitute(template_text)
-        self.setText(template_text)
-
-        # Set the title.
-        employee = self.get_employee()
-        title = template_object.Title()
-        if employee is not None:
-            numbers = [0]
-            for contract in employee.getFolderContents(
-                dict(portal_type=self.portal_type)):
-                if not contract.Title.startswith(title):
-                    continue
-                number = contract.Title.split(' ')[-1]
-                try:
-                    numbers.append(int(number))
-                except ValueError:
-                    continue
-            title += ' %d' % (max(numbers) + 1)
-        self.title = title
-
     security.declarePublic('template_chosen')
     def template_chosen(self):
         """Determine if the template (a string) has been chosen yet.
